#!/usr/bin/ksh
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2013 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

# -----------------------------------------------------------------------
# Retrieves the access state of the MEP.
#
# @param
#	user=<DS user>
#	password=<DS password>
#	ipaddress=<ip of mep>
#	type=<MEP type>
#
# @return
#	result=success
#			Overall operation succeed
#	
#	state=<access state>
#			Valid for a success result. Indicates the access state of 
#			the MEP
#
#	result=notfound
#			In case MEP was not found in Systems Director
#
#	result=fail_retrieve
#			In case error occurred when attempting to retrieve the MEP
#			from Systems Director
#
#	result=fail_auth
#			Failed to invoke smcli with DS credentials supplied
#
#	result=fail
#		In case general error occurred when attempting to retrieve the
#		access state of the MEP.
#
# ------------------------------------------------------------------------

user="$(echo $1 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"
password="$(echo $2 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"
ipaddress="$(echo $3 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"
mep_type="$(echo $4 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"

# -------------------------------------------------------------------------
# At first just check that command works (i/o redirect -- we do not
# want to see its output)
# -------------------------------------------------------------------------
smcli -user $user -pw $password lssys -t $mep_type -i $ipaddress -A AccessState  > /dev/null 2>&1
RC=$?

if [ "$RC" = "3" ]; then
        echo "result=fail_auth"
        exit 0;
fi

if [ "$RC" = "20" ]; then
        echo "result=notfound"
        exit 0;
fi

if [ "$RC" != "0" ]; then
        echo "result=fail_retrieve"
        exit 0;
fi

# Trying again
output="$(smcli -user $user -pw $password lssys -t $mep_type -i $ipaddress -A AccessState)"
# -------------------------------------------------------------------------
# Due to a bug in smcli lssys it can return RC=0 but without any data
# (empty line)
# -------------------------------------------------------------------------
if [ "x$output" = "x" ]; then
	echo "result=notfound"
	exit 0;
fi

# Use grep to search for the pattern that includes the last colon followed by a space
# and then the state: ': Unlocked', ': Locked', ': PartiallyLocked'
# Any other result will result in state=Unknown
echo $output | grep ": Unlocked" >/dev/null 2>&1
RC=$?
if [ "$RC" = "0" ]; then
        echo "result=success,state=Unlocked"
        exit 0;
fi

echo $output | grep ": Locked" >/dev/null 2>&1
RC=$?
if [ "$RC" = "0" ]; then
        echo "result=success,state=Locked"
        exit 0;
fi

echo $output | grep ": PartiallyLocked" >/dev/null 2>&1
RC=$?
if [ "$RC" = "0" ]; then
        echo "result=success,state=PartiallyLocked"
        exit 0;
fi
 
# Not locked, not unlocked and not partially locked, just return unknown
echo "result=success,state=Unknown"
