#!/usr/bin/ksh
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2013 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

# -----------------------------------------------------------------------
# Removed the MEP indicated by its type and IP address
#
# @param
#	user=<DS user>
#	password=<DS password>
#	ipaddress=<ip of mep>
#	type=<MEP type>
#
# @return
#	result=success
#			Overall operation succeed
#	
#	result=fail_auth
#			Failed to invoke smcli with DS credentials supplied.
#
#	result=notfound
#			The MEP with given IP address was not found in Systems Director
#	
#	result=cannot_remove
#			The MEP can not be removed
#
#	result=fail_retrieve
#		In case error occurred when attempting to retrieve the MEP OID
#		from Systems Director
#
# ------------------------------------------------------------------------

user="$(echo $1 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"
password="$(echo $2 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"
ipaddress="$(echo $3 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"
mep_type="$(echo $4 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"

# -----------------------------------------------------------------------
# At first just check that command works (i/o redirect -- we do not
# want to see its output)
# -------------------------------------------------------------------------
smcli -user $user -pw $password lssys -p -i $ipaddress -t $mep_type > /dev/null 2>&1
RC=$?

if [ "$RC" = "3" ]; then
        echo "result=fail_auth"
        exit 0;
fi

if [ "$RC" = "20" ]; then
        echo "result=notfound"
        exit 0;
fi

if [ "$RC" != "0" ]; then
        echo "result=fail_retrieve"
        exit 0;
fi

# Trying again
mep_oid="$(smcli -user $user -pw $password lssys -p -i $ipaddress -t $mep_type)"
# -------------------------------------------------------------------------
# Due to a bug in smcli lssys it can return RC=0 but without any data
# (empty line)
# -------------------------------------------------------------------------
if [ "x$mep_oid" = "x" ]; then
	echo "result=notfound"
	exit 0;
fi

mep_oid_no_spaces=`echo $mep_oid | sed -e 's/^ *//' -e 's/ *$//'`

smcli -user $user -pw $password rmsys -n $mep_oid_no_spaces > /dev/null 2>&1
RC=$?

if [ "$RC" = "3" ]; then
        echo "result=fail_auth"
        exit 0;
fi

if [ "$RC" = "50" ]; then
        echo "result=cannot_remove"
        exit 0;
fi

# -----------------------------------------------------------------------
# Not sure if we want to check other RCs here since it seems that remove might 
# report as failed even though it succeed. We can add presence check here..
# -------------------------------------------------------------------------

echo "result=success"
