#!/usr/bin/ksh
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2013 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

# --------------------------------------------------------------------------
# NOTE: This script is currently being used apart from reset director agent 
# keys only
#
# Stops agent services all together (this includes CA and PA services)
#
# @return
#	result=success
#			Overall operation succeed.
#
#	result=fail
#			Overall operation failed.
#
#	need_to_start_pa={yes, no}
#			Applicable for result=success. PA services were active before, so 
#			they should be started after the reset operation.
#
#	need_to_start_ca={yes, no}
#			Applicable for result=success. CA service was active before, so
#			we indicate that it should be started after the reset operation.
#
# ---------------------------------------------------------------------------

#---------------------------------------------------------------------------
# Utility function to wait for the specified subsystem to stop.
#
#	@param susbsystem service name
#	@return 0 subsystem reported as stopped during the predefined elapsed 
#	time
#	@return 1 subsystem not being reported stopped during the predefined
#	elapsed time
#
#---------------------------------------------------------------------------
function wait_for_service_to_stop {
	
	for i in 1 2 3 4 5 6 7 8 9 10
	do
		sleep 20
		/usr/bin/lssrc -s $1 | grep -i inoperative  >/dev/null 2>&1
		res=$?
		if [ "$res" = "0" ]; then
			break
		else
			echo "dummy" > /dev/null
		fi
		if [ "$i" = "10" ]; then
			return 1
		fi
	done
	
	return 0
}

need_to_start_pa="no"
# -----------------------------------------------
# Platform agent subsystem available?
# -----------------------------------------------
/usr/bin/lssrc -s platform_agent | grep -i active >/dev/null 2>&1
RC=$?
if [ "$RC" = "0" ]; then
        need_to_start_pa="yes"
       	/usr/bin/stopsrc -s platform_agent >/dev/null 2>&1
       	wait_for_service_to_stop "platform_agent"
       	RC=$?
		if [ "$RC" != "0" ]; then
        	echo "result=fail,platform_agent_RC=stop_fail"
        	exit 0;
		fi
else
		need_to_start_pa="no"
fi

need_to_start_ca="no"
# -----------------------------------------------
# Common agent installed? (for now check to see
# if endpoint.sh available)
# -----------------------------------------------
if [ -x /opt/ibm/director/agent/runtime/agent/bin/endpoint.sh ]; then
	
	/opt/ibm/director/agent/runtime/agent/bin/endpoint.sh status | grep Subsystem >/dev/null 2>&1
	RC=$?
	if [ "$RC" = "0" ]; then
		# ---------------------------------------------------
		# This endpoint.sh status uses the new status format
		# (subsystem status)
		# ---------------------------------------------------
		/opt/ibm/director/agent/runtime/agent/bin/endpoint.sh status | grep -i active >/dev/null 2>&1
		status_RC=$?	
	else
		# ---------------------------------------------------
		# This endpoint.sh status uses the new old status 
		# format (of the nonstop service)
		# ---------------------------------------------------
		/opt/ibm/director/agent/runtime/agent/bin/endpoint.sh status | grep -i running >/dev/null 2>&1
		status_RC=$?
	fi
	
	if [ "$status_RC" = "0" ]; then
		need_to_start_ca="yes"
	else
		need_to_start_ca="no"
	fi
	
	/opt/ibm/director/agent/runtime/agent/toolkit/bin/configure.sh -unmanaged -force >/dev/null 2>&1
	
	# -----------------------------------------------
	# Give some time for the agent to initialize
	# before we stop it
	# -----------------------------------------------
	sleep 10
	
	# -----------------------------------------------
	# Unmanaged operation might start common agent 
	# even though it was stopped before so explicit
	# stop it.
	# -----------------------------------------------
	/opt/ibm/director/agent/runtime/agent/bin/endpoint.sh stop >/dev/null 2>&1
	/opt/ibm/director/agent/runtime/agent/bin/endpoint.sh status | grep Subsystem >/dev/null 2>&1
	RC=$?
	if [ "$RC" = "0" ]; then
		# ---------------------------------------------------
		# This endpoint.sh status uses the new status format
		# (subsystem status) so wait till being stopped
		# ---------------------------------------------------
		wait_for_service_to_stop "cas_agent"
		RC=$?
		if [ "$RC" != "0" ]; then
        	echo "result=fail,common_RC=stop_fail"
        	exit 0;
		fi
	fi
fi

echo "result=success,need_to_start_pa=$need_to_start_pa,need_to_start_ca=$need_to_start_ca"
