#! /bin/bash
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2013 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

# -----------------------------------------------------------------------
# Searches endpoint.properties for to retrieve agent information.
#
# @return
#	result=fail 
#				In case property file not found
#	
#	result=success,agent_am_ip=<unmanaged, agent manager IP>,agent_port=<port number>,
#	agent_non_stop_port1=<9514>,agent_non_stop_port2=<9515>
#
#				* unmanaged - in case unmanagedAgent property set to true
#				
#				* agent manager IP - in case unmanagedAgent property not
#				not set to true and value is taken from AgentManagerQuery.Host
#				
#				* agent_port - value of ep.port property
#				* agent_non_stop_port1 - currently hard coded
#				* agent_non_stop_port2 - currently hard coded
#				
# ------------------------------------------------------------------------

endpoint_props="/opt/ibm/director/agent/runtime/agent/config/endpoint.properties"
if [ ! -e "$endpoint_props" ]; then
        echo "result=fail"
        exit 0;
fi

unmanaged="$(cat "$endpoint_props" | grep unmanagedAgent | awk '{{split($0, split_result, "=")} {print split_result[2]}}')"
ipaddress="$(cat "$endpoint_props" | grep AgentManagerQuery.Host | awk '{{split($0, split_result, "=")} {print split_result[2]}}')"
ep_port="$(cat "$endpoint_props" | grep ep.port | awk '{{split($0, split_result, "=")} {print split_result[2]}}')"

if [ "$unmanaged" = "true" ]; then
	echo "result=success,agent_am_ip=unmanaged,agent_port=$ep_port,agent_non_stop_port1=9514,agent_non_stop_port2=9515"
	exit 0;
fi

echo "result=success,agent_am_ip=$ipaddress,agent_port=$ep_port,agent_non_stop_port1=9514,agent_non_stop_port2=9515"
