#! /bin/bash
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2013 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

# -----------------------------------------------------------------------
# Returns default agent manager information (the one that Director is using)
#
# @param
# user=<DS user>
# password=<DS password>
#
# @return
#
#	result=fail_auth
#				Failed to invoke smcli with DS credentials supplied.
#	result=fail 
#				In case a failure occurred while retrieving agent manager
#				information
#	
#	result=success,ds_am_ip=<agent manager IP>
#				This is the IP address of the Agent Manager Director is 
#				configured with
#
# ------------------------------------------------------------------------
user="$(echo $1 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"
password="$(echo $2 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"

# -------------------------------------------------------------------------
# At first just check that commands work (i/o redirect -- we do not
# want to see its output)
# -------------------------------------------------------------------------
smcli -user $user -pw $password getDefaultAgentManager > /dev/null 2>&1
RC=$?
if [ "$RC" = "3" ]; then
        echo "result=fail_auth"
        exit 0;
fi

smcli -user $user -pw $password getAgentManagers > /dev/null 2>&1
RC=$?
if [ "$RC" = "3" ]; then
        echo "result=fail_auth"
        exit 0;
fi

# ---------------------------------------------
# First, retrieve the default agent manager
# ID.
# ---------------------------------------------
default_am_id="$(smcli -user $user -pw $password getDefaultAgentManager | awk '{ {split($0, split_result, ":")} {print split_result[2]} }')"
default_am_id_no_spaces=${default_am_id/ /}

# ---------------------------------------------
# Second, retrieve the default agent manager
# IP address. We rely on the fact that IP line
# is the 2nd line after the ID.
# ---------------------------------------------
ipaddress="$(smcli -user $user -pw $password getAgentManagers | grep -A 2 $default_am_id_no_spaces | grep "Agent manager ip" | awk '{ {split($0, split_result, ":")} {print split_result[2]} }')"
ip_no_spaces=${ipaddress/ /}

echo "result=success,ds_am_ip=$ip_no_spaces"
