#! /bin/bash
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2013 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

# -----------------------------------------------------------------------
# Reports whether MEP is CAS.
#
# @param
#	user=<DS user>
#	password=<DS password>
#	ipaddress=<ip of mep>
#	type=<MEP type>
#
# @return
#	result=success
#			Overall operation succeed
#
#	is_cas={true, false}
#			Relevant for a success result only. Indicates whether the MEP
#			CAS or not.
#
#	result=notfound
#			In case MEP was not found in Systems Director
#
#	result=fail_auth
#			Failed to invoke smcli with DS credentials supplied.
#
#	result=fail
#		In case general error occurred when attempting to check whether the
#		MEP is CAS or not.
#
# ------------------------------------------------------------------------

user="$(echo $1 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"
password="$(echo $2 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"
ipaddress="$(echo $3 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"
mep_type="$(echo $4 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"

# First time just to check error code with i/o redirection
smcli -user $user -pw $password lssys -t $mep_type -i $ipaddress -A Protocols > /dev/null 2>&1
RC=$?

if [ "$RC" = "3" ]; then
        echo "result=fail_auth"
        exit 0;
fi

if [ "$RC" = "20" ]; then
        echo "result=notfound"
        exit 0;
fi

if [ "$RC" != "0" ]; then
        echo "result=fail"
        exit 0;
fi

# -------------------------------------------------------------------------
# Due to a bug in smcli lssys it can return RC=0 but without any data
# (empty line)
# -------------------------------------------------------------------------
output="$(smcli -user $user -pw $password lssys -t $mep_type -i $ipaddress -A Protocols)"
if [ "x$output" = "x" ]; then
	echo "result=notfound"
	exit 0;
fi


# Trying again
output="$(smcli -user $user -pw $password lssys -t $mep_type -i $ipaddress -A Protocols |  grep "'CAS'")"
output_no_spaces=${output/ /}

case "$output_no_spaces" in
    *CAS* ) echo "result=success,is_cas=true"; exit 0;;
    * ) echo "result=success,is_cas=false";;
esac
