#!/bin/sh
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2013 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

# -----------------------------------------------------------------------
# Register / unregister dummy SLP service (service:ddf_dummy) against 
# endpoint SLP SA
# 
# @param
#	ipaddress=<host ip>
#				The IP address of the host to register/unregister the dummy SLP on
#	operation=<register | unregister>
#				The operation: register or unregister
#
# @return
#	result=notfound
#			No SLP registration utility found.
#
#	result=fail
#			SLP registration / de-registration fail
#
#	result=success
#			SLP registration completed successfully
#
# ------------------------------------------------------------------------

ipaddress="$(echo $1 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"
operation="$(echo $2 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"

if [ -e /opt/ibm/icc/bin/slptool ]; then
	slp_reg_tool="/opt/ibm/icc/bin/slptool"
fi

if [ $slp_reg_tool"X" = "X" ]; then
	echo "result=notfound"
	exit 0;
fi

if [ "$operation" = "register" ]; then
	$slp_reg_tool register service:ddf_dummy://$ipaddress "(description=It is for DDF test)" >/dev/null 2>&1
	RC=$?
	if [ "$RC" = "0" ]; then
		echo "result=success"
	else
		echo "result=fail"
	fi
fi

if [ "$operation" = "unregister" ]; then
	$slp_reg_tool deregister service:ddf_dummy://$ipaddress >/dev/null 2>&1
	
	RC=$?
	if [ "$RC" = "0" ]; then
		echo "result=success"
	else
		echo "result=fail"
	fi
fi

exit 0
