#! /bin/bash
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2013 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

# --------------------------------------------------------------------------
# NOTE: This script is currently being used as part of reset director agent 
# keys only
#
# Stops agent services all together (this includes CA and PA services)
#
# @return
#	result=success
#			Overall operation succeed.
#
#	result=fail
#			Overall operation failed.
#
#	need_to_start_pa={yes, no}
#			Applicable for result=success. PA services were active before, so 
#			they should be started after the reset operation.
#
#	need_to_start_ca={yes, no}
#			Applicable for result=success. CA service was active before, so
#			we indicate that it should be started after the reset operation.
#
# ---------------------------------------------------------------------------

need_to_start_pa="no"
# -----------------------------------------------
# Platform agent installed? (for now check to see
# if cimserverd available and if yes then stop it)
# -----------------------------------------------
if [ -x /etc/init.d/cimserverd ]; then
	
	cimserver_status="$(/etc/init.d/cimserverd status | grep -i running)"
	if [ "x$cimserver_status" = "x" ]; then
		need_to_start_pa="no"
	else
		need_to_start_pa="yes"
		# ---------------------------------------------
		# Watchdog added into DS 6.3 agents
		# Nothing happens if already stopped
		# ---------------------------------------------
		if [ -e /etc/init.d/ibmpawatchdogd ]; then
			/etc/init.d/ibmpawatchdogd stop > /dev/null 2>&1
		fi
		/etc/init.d/cimserverd stop > /dev/null 2>&1
		/etc/init.d/tier1slpinst stop > /dev/null 2>&1
		/etc/init.d/cimlistenerd stop > /dev/null 2>&1
	fi
fi

need_to_start_ca="no"
# -----------------------------------------------
# Common agent installed? (for now check to see
# if endpoint.sh available)
# -----------------------------------------------
if [ -x /opt/ibm/director/agent/runtime/agent/bin/endpoint.sh ]; then
	
	common_status="$(/opt/ibm/director/agent/runtime/agent/bin/endpoint.sh status | grep -i running)"
	if [ "x$common_status" = "x" ]; then
		need_to_start_ca="no"
	else
		need_to_start_ca="yes"
	fi
	
	/opt/ibm/director/agent/runtime/agent/toolkit/bin/configure.sh -unmanaged -force >/dev/null 2>&1
	
	# -----------------------------------------------
	# Give some time for the agent to initialize
	# before we stop it
	# -----------------------------------------------
	sleep 10
	
	# -----------------------------------------------
	# Unmanaged operation might start common agent 
	# even though it was stopped before so explicit
	# stop it.
	# -----------------------------------------------
	# ---------------------------------------------
	# Watchdog added into DS 6.3 agents
	# Note: Nothing happens if already stopped
	# ---------------------------------------------
	if [ -e /etc/init.d/ibmpawatchdogd ]; then
		/etc/init.d/ibmpawatchdogd stop > /dev/null 2>&1
	fi
	/opt/ibm/director/agent/runtime/agent/bin/endpoint.sh stop >/dev/null 2>&1
fi

echo "result=success,need_to_start_pa=$need_to_start_pa,need_to_start_ca=$need_to_start_ca"
