@echo off
REM Licensed Materials - Property of IBM
REM
REM (C) Copyright IBM Corp. 2013 All Rights Reserved
REM
REM US Government Users Restricted Rights - Use, duplicate or
REM disclosure restricted by GSA ADP Schedule Contract with
REM IBM Corp.

rem -----------------------------------------------------------------------
rem Use EnableDelayedExpansion so that we can refer to variables from inside
rem for loops.
rem -------------------------------------------------------------------------
Setlocal EnableDelayedExpansion

rem -----------------------------------------------------------------------
rem Returns default agent manager information (the one that Director is using)
rem
rem @param
rem user=<DS user>
rem password=<DS password>
rem
rem @return
rem
rem result=fail_auth
rem		Failed to invoke smcli with DS credentials supplied.
rem
rem	result=fail 
rem				In case a failure occurred while retrieving agent manager
rem				information
rem	
rem	result=success,ds_am_ip=<agent manager IP>
rem				This is the IP address of the Agent Manager Director is 
rem				configured with
rem
rem ------------------------------------------------------------------------

set user=%2
set password=%4

rem ------------------------------------------------------------------------
rem At first just check that command works (i/o redirect -- we do not
rem want to see its output)
rem -------------------------------------------------------------------------

smcli -user %user% -pw %password% getDefaultAgentManager >NUL 2>NUL

if %ERRORLEVEL% equ 3 (
        echo result=fail_auth
        exit /b 0
)

smcli -user %user% -pw %password% getAgentManagers >NUL 2>NUL

if ERRORLEVEL 3 (

	if ERRORLEVEL 4 (
		goto CONTINUE
	)
	
	rem ------------------------
	rem Exactly 3 - authentication
	rem error
	rem ------------------------
	echo result=fail_auth
	exit /b 0
)

:CONTINUE

rem ---------------------------------------------
rem First, retrieve the default agent manager
rem ID.
rem ---------------------------------------------
for /f "tokens=2 delims=:" %%a in ('smcli -user %user% -pw %password% getDefaultAgentManager') do (
	set default_am_id=%%a
)

rem -----------------------------------------------------------------------
rem Extract leading space resulted from previous command output
rem -------------------------------------------------------------------------

for /f "tokens=1 delims= " %%a in ("%default_am_id%") do set default_am_id_no_spaces=%%a

set is_default_agent_manager=false
for /f "tokens=1-5 delims= " %%a in ('smcli -user %user% -pw %password% getAgentManagers') do (
	
	if "%%a"=="Agent" (
   		if "%%b"=="manager" (
   			if "%%c"=="id/name" (
   				if "%%e"=="%default_am_id_no_spaces%" (set is_default_agent_manager=true)
   			)
   		)
   	)
   	
   	if "%%a"=="Agent" (
   		if "%%b"=="manager" (
   			if "%%c"=="ip" (
   				rem --------------------------------------
   				rem When using EnableDelayedExpansion we
   				rem must refer to a variable using ! !
   				rem --------------------------------------
   				if "!is_default_agent_manager!"=="true" (
   					echo result=success,ds_am_ip=%%e
   					exit /b 0
   				)	
   			)
   		)
   	)

rem for
)


echo result=fail
exit /b 0
