@echo off
REM Licensed Materials - Property of IBM
REM
REM (C) Copyright IBM Corp. 2013 All Rights Reserved
REM
REM US Government Users Restricted Rights - Use, duplicate or
REM disclosure restricted by GSA ADP Schedule Contract with
REM IBM Corp.

rem --------------------------------------------------------------------------
rem Restarts the the various services as denoted by the given agent type.
rem
rem @param
rem	agent_type=<common, platform>
rem			Common Agent or Platform Agent.
rem
rem			The following services will be restarted for Common Agent 
rem 		(taken from CAS trouble shooter guide):
rem			0. ibmpawatchdog - stop
rem			1. IBMTivoliCommonAgent - stop
rem			2. wmicimserver - stop
rem			3. tier1slp - stop
rem			4. ibmsa - stop
rem
rem			5. ibmsa - start
rem			6. tier1slp - start
rem			7. wmicimserver - start
rem			8. IBMTivoliCommonAgent (common agent) - start
rem			9. ibmpawatchdog - start
rem
rem			The following services will be restarted for Platform Agent
rem 		(following is from infocenter - windows section, but am not sure if order is correct so I 
rem			changed actual order to be like in linux):
rem			0. ibmpawatchdog - stop
rem			1. wmicimserver - stop
rem			2. tier1slp - stop
rem			3. cimlistenerd - stop
rem			4. ibmsa - stop
rem
rem			5. ibmsa - start
rem			6. cimlistenerd - start
rem			7. tier1slp - start
rem			8. wmicimserver start
rem			9. ibmpawatchdog - start
rem
rem @return
rem	result=success
rem			Overall operation succeed. No errors returned by the start command
rem
rem	result=fail
rem			Overall operation failed. At least one command was not found
rem			or at least one start command failed. The following values can be
rem 			set to provide more detail:
rem
rem				slp_RC={start_fail, notfound}
rem				common_RC={start_fail, notfound}
rem				cimlistener_RC={start_fail, notfound}
rem				cimserver_RC={start_fail, notfound}
rem				tier1slp_RC={start_fail, notfound}
rem ---------------------------------------------------------------------------

set agent_type=%2

rem -----------------------------------------------
rem
rem Let's stop and start the services for the
rem Common Agent
rem
rem -----------------------------------------------

if "%agent_type%"=="platform" (

	net stop ibmpawatchdog >NUL 2>NUL
	net stop wmicimserver >NUL 2>NUL
	net stop tier1slp >NUL 2>NUL
	net stop cimlistener >NUL 2>NUL
	net stop ibmsa >NUL 2>NUL
	
	net start ibmsa >NUL 2>NUL
	IF ERRORLEVEL 1 (
        echo result=fail,slp_RC=start_fail
        exit /b 0
	)

	net start cimlistener >NUL 2>NUL
	IF ERRORLEVEL 1 (
        echo result=fail,cimlistener_RC=start_fail
        exit /b 0
	)
	
	net start tier1slp >NUL 2>NUL
	IF ERRORLEVEL 1 (
        echo result=fail,tier1slp_RC=start_fail
        exit /b 0
	)
	
	net start wmicimserver >NUL 2>NUL
	IF ERRORLEVEL 1 (
        echo result=fail,cimserver_RC=start_fail
        exit /b 0
	)
	
	net start ibmpawatchdog >NUL 2>NUL
	IF ERRORLEVEL 1 (
        echo result=fail,watchdog_RC=start_fail
        exit /b 0
	)
	
	echo result=success
	exit /b 0
)

if "%agent_type%"=="common" (

	net stop ibmpawatchdog >NUL 2>NUL
	net stop IBMTivoliCommonAgent0 >NUL 2>NUL
	net stop wmicimserver >NUL 2>NUL
	net stop tier1slp >NUL 2>NUL
	net stop ibmsa >NUL 2>NUL
	
	net start ibmsa >NUL 2>NUL
	IF ERRORLEVEL 1 (
        echo result=fail,slp_RC=start_fail
        exit /b 0
	)
	
	net start tier1slp >NUL 2>NUL
	IF ERRORLEVEL 1 (
        echo result=fail,tier1slp_RC=start_fail
        exit /b 0
	)

	net start wmicimserver >NUL 2>NUL
	IF ERRORLEVEL 1 (
        echo result=fail,cimserver_RC=start_fail
        exit /b 0
	)

	net start IBMTivoliCommonAgent0 >NUL 2>NUL
	IF ERRORLEVEL 1 (
        echo result=fail,common_RC=start_fail
        exit /b 0
	)
	
	net start ibmpawatchdog >NUL 2>NUL
	IF ERRORLEVEL 1 (
        echo result=fail,watchdog_RC=start_fail
        exit /b 0
	)
	
	echo result=success
	exit /b 0
)
