@echo off
REM Licensed Materials - Property of IBM
REM
REM (C) Copyright IBM Corp. 2013 All Rights Reserved
REM
REM US Government Users Restricted Rights - Use, duplicate or
REM disclosure restricted by GSA ADP Schedule Contract with
REM IBM Corp.

rem -----------------------------------------------------------------------
rem Reports whether Director server's resource manager can correctly 
rem interact with its Agent Manager (by querying, for example, its 
rem registered agents).
rem
rem @param
rem user=<DS user>
rem password=<DS password>
rem
rem @return
rem
rem result=fail_auth
rem		Failed to invoke smcli with DS credentials supplied.
rem
rem	result=fail 
rem				In case a failure occurred while interacting with 
rem				Agent Manager. Note: we currently report 'fail' in case we 
rem				did not receive any agent. The local MEP CAS agent must be
rem				returned and if not, then there must be some issue..
rem	
rem	result=success
rem				In case a successful interaction occurred with 
rem				Agent Manager. Note: we report 'success' in case we 
rem				receive at least one agent. The local MEP CAS agent must be
rem				returned.
rem
rem ------------------------------------------------------------------------

set user=%2
set password=%4

rem ------------------------------------------------------------------------
rem At first just check that command works (i/o redirect -- we do not
rem want to see its output)
rem -------------------------------------------------------------------------

smcli -user %user% -pw %password% getDefaultAgentManager >NUL 2>NUL

if %ERRORLEVEL% equ 3 (
        echo result=fail_auth
        exit /b 0
)

rem ---------------------------------------------
rem First, retrieve the default agent manager
rem ID.
rem ---------------------------------------------
for /f "tokens=2 delims=:" %%a in ('smcli -user %user% -pw %password% getDefaultAgentManager') do (
	set default_am_id=%%a
)

rem -----------------------------------------------------------------------
rem Extract leading space resulted from previous command output
rem -------------------------------------------------------------------------

for /f "tokens=1 delims= " %%a in ("%default_am_id%") do set default_am_id_no_spaces=%%a

rem ------------------------------------------------------------------------
rem At first just check that command works (i/o redirect -- we do not
rem want to see its output)
rem -------------------------------------------------------------------------

smcli -user %user% -pw %password% queryAllAgentsByAM %default_am_id_no_spaces% >NUL 2>NUL

if ERRORLEVEL 3 (

	if ERRORLEVEL 4 (
		goto CONTINUE
	)
	
	rem ------------------------
	rem Exactly 3 - authentication
	rem error
	rem ------------------------
	echo result=fail_auth
	exit /b 0
)

:CONTINUE

set query_agents_command=smcli -user %user% -pw %password% queryAllAgentsByAM %default_am_id_no_spaces% ^| findstr /B "Agent"

rem --------------------------------------------------------------
rem The first line of agent information starts with "Agent"
rem If not output or error message being returned -- then it will
rem not include "Agent" right at the beginning of the line - so 
rem seems we are ok.
rem --------------------------------------------------------------
for /f "tokens=1" %%a in ('"call %query_agents_command%"') do (
    if "%%a"=="Agent" GOTO SUCCSESS
)

echo result=fail
GOTO FINAL
	
:SUCCSESS

echo result=success
GOTO FINAL

:FINAL
exit /b 0
